import withRender from "./index.vtpl";
import './index.less';

let uid = 0;

export default withRender({
    name: 'ScrollLoadingContainer',
    props: {
        scrollToBottom: {
            type: Function,
            default: function () {

            }
        },
        height: {
            type: String,
        },
        isWaiting: {
            type: Boolean,
            default: true,
        }
    },
    data() {
        return {
            key: `scrollContainer${uid}`,
        }
    },
    staticData: {
        isLoading: false
    },
    created() {
        uid++;
    },
    methods: {
        stop() {
            this.$options.staticData.isLoading = false;
        },
        start() {
            this.$options.staticData.isLoading = true;
        },
        isCanExecute() {
            if (this.isWaiting) {
                return !this.$options.staticData.isLoading;
            }
            return true;
        }
    },
    mounted() {
        const viewContent = this.$refs[this.key];
        this.onScroll = () => {
            if (this.isCanExecute()) {
                const scT = viewContent.scrollTop;
                const scH = viewContent.scrollHeight;
                const cH = viewContent.clientHeight;
                if (scT + cH >= scH - 5) {
                    this.start();
                    this.scrollToBottom(this.stop);
                }
            }
        };
        viewContent.addEventListener('scroll', this.onScroll, false);
    },
    beforeDestroy() {
        const viewContent = this.$refs[this.key];
        viewContent.removeEventListener('scroll', this.onScroll, false)
    }
});
